@@ -17,28 +17,34 @@ extensions = [
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'redis-lock'
-year = '2013-2020'
+year = '2013-2022'
 author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '3.6.0'
+version = release = '4.0.0'
 
+linkcheck_ignore = [
+    # This redirects to hosted % image on AWS.
+    'https://coveralls\\.io/repos/ionelmc/python\\-redis\\-lock/badge\\.svg\\?branch=master\\&service=github',
+    # This anchor is incorrectly marked as missing. GH bug?
+    'https://github\\.com/jazzband/django\\-redis\\#configure\\-as\\-cache\\-backend',
+]
 pygments_style = 'trac'
 templates_path = ['.']
 extlinks = {
     'issue': ('https://github.com/ionelmc/python-redis-lock/issues/%s', '#'),
     'pr': ('https://github.com/ionelmc/python-redis-lock/pull/%s', 'PR #'),
 }
-html_theme = "sphinx_py3doc_enhanced_theme"
+html_theme = 'sphinx_py3doc_enhanced_theme'
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
 html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-redis-lock/'
+    'githuburl': 'https://github.com/ionelmc/python-redis-lock/',
 }
 
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = False
 html_sidebars = {
-   '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
+    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
 
