@@ -7,7 +7,8 @@ from sched import scheduler
 
 from redis import StrictRedis
 
-from redis_lock import Lock, logger
+from redis_lock import Lock
+from redis_lock import logger
 
 logging.basicConfig(level="WARN", format="%(message)s")
 logger.setLevel("WARN")
@@ -61,15 +62,7 @@ logging.critical("Implementation Lock duration Concurrency Acquires: Total
 logging.critical("============== ============= =========== ========= ========== ========== ========== ==========")
 
 
-for concurrency in (
-    1,
-    2,
-    3,
-    6,
-    12,
-    24,
-    48
-):
+for concurrency in (1, 2, 3, 6, 12, 24, 48):
     for duration in (
         0,
         0.01,
@@ -87,11 +80,20 @@ for concurrency in (
             if concurrency > 1:
                 logging.critical(
                     "%14s %12.3fs %11s %20s %10.2f %10s %10s",
-                    type_, duration, concurrency, sum(ret), sum(ret) / len(ret), min(ret), max(ret)
+                    type_,
+                    duration,
+                    concurrency,
+                    sum(ret),
+                    sum(ret) / len(ret),
+                    min(ret),
+                    max(ret),
                 )
             else:
                 logging.critical(
                     "%14s %12.3fs %11s %20s",
-                    type_, duration, concurrency, sum(ret),
+                    type_,
+                    duration,
+                    concurrency,
+                    sum(ret),
                 )
 logging.critical("============== ============= =========== ========= ========== ========== ========== ==========")
