@@ -1,25 +1,20 @@
-import sys
 import threading
 import weakref
 from base64 import b64encode
 from logging import getLogger
 from os import urandom
+from typing import Union
 
 from redis import StrictRedis
 
-__version__ = '3.6.0'
-
-logger = getLogger(__name__)
-
-PY3 = sys.version_info[0] == 3
-
-if PY3:
-    text_type = str
-    binary_type = bytes
-else:
-    text_type = unicode  # noqa
-    binary_type = str
+__version__ = '4.0.0'
 
+logger_for_acquire = getLogger(f"{__name__}.acquire")
+logger_for_refresh_thread = getLogger(f"{__name__}.refresh.thread")
+logger_for_refresh_start = getLogger(f"{__name__}.refresh.start")
+logger_for_refresh_shutdown = getLogger(f"{__name__}.refresh.shutdown")
+logger_for_refresh_exit = getLogger(f"{__name__}.refresh.exit")
+logger_for_release = getLogger(f"{__name__}.release")
 
 # Check if the id match. If not, return an error code.
 UNLOCK_SCRIPT = b"""
@@ -99,11 +94,15 @@ class Lock(object):
     """
     A Lock context manager implemented via redis SETNX/BLPOP.
     """
+
     unlock_script = None
     extend_script = None
     reset_script = None
     reset_all_script = None
 
+    _lock_renewal_interval: float
+    _lock_renewal_thread: Union[threading.Thread, None]
+
     def __init__(self, redis_client, name, expire=None, id=None, auto_renewal=False, strict=True, signal_expire=1000):
         """
         :param redis_client:
@@ -134,8 +133,7 @@ class Lock(object):
             Advanced option to override signal list expiration in milliseconds. Increase it for very slow clients. Default: ``1000``.
         """
         if strict and not isinstance(redis_client, StrictRedis):
-            raise ValueError("redis_client must be instance of StrictRedis. "
-                             "Use strict=False if you know what you're doing.")
+            raise ValueError("redis_client must be instance of StrictRedis. Use strict=False if you know what you're doing.")
         if auto_renewal and expire is None:
             raise ValueError("Expire may not be None when auto_renewal is set")
 
@@ -152,20 +150,18 @@ class Lock(object):
         self._signal_expire = signal_expire
         if id is None:
             self._id = b64encode(urandom(18)).decode('ascii')
-        elif isinstance(id, binary_type):
+        elif isinstance(id, bytes):
             try:
                 self._id = id.decode('ascii')
             except UnicodeDecodeError:
                 self._id = b64encode(id).decode('ascii')
-        elif isinstance(id, text_type):
+        elif isinstance(id, str):
             self._id = id
         else:
-            raise TypeError("Incorrect type for `id`. Must be bytes/str not %s." % type(id))
+            raise TypeError(f"Incorrect type for `id`. Must be bytes/str not {type(id)}.")
         self._name = 'lock:' + name
         self._signal = 'lock-signal:' + name
-        self._lock_renewal_interval = (float(expire) * 2 / 3
-                                       if auto_renewal
-                                       else None)
+        self._lock_renewal_interval = float(expire) * 2 / 3 if auto_renewal else None
         self._lock_renewal_thread = None
 
         self.register_scripts(redis_client)
@@ -174,11 +170,11 @@ class Lock(object):
     def register_scripts(cls, redis_client):
         global reset_all_script
         if reset_all_script is None:
-            reset_all_script = redis_client.register_script(RESET_ALL_SCRIPT)
             cls.unlock_script = redis_client.register_script(UNLOCK_SCRIPT)
             cls.extend_script = redis_client.register_script(EXTEND_SCRIPT)
             cls.reset_script = redis_client.register_script(RESET_SCRIPT)
             cls.reset_all_script = redis_client.register_script(RESET_ALL_SCRIPT)
+            reset_all_script = redis_client.register_script(RESET_ALL_SCRIPT)
 
     @property
     def _held(self):
@@ -196,7 +192,7 @@ class Lock(object):
 
     def get_owner_id(self):
         owner_id = self._client.get(self._name)
-        if isinstance(owner_id, binary_type):
+        if isinstance(owner_id, bytes):
             owner_id = owner_id.decode('ascii', 'replace')
         return owner_id
 
@@ -207,7 +203,7 @@ class Lock(object):
         :param timeout:
             An integer value specifying the maximum number of seconds to block.
         """
-        logger.debug("Getting %r ...", self._name)
+        logger_for_acquire.debug("Acquiring Lock(%r) ...", self._name)
 
         if self._held:
             raise AlreadyAcquired("Already acquired from this Lock instance.")
@@ -218,10 +214,10 @@ class Lock(object):
         if timeout:
             timeout = int(timeout)
             if timeout < 0:
-                raise InvalidTimeout("Timeout (%d) cannot be less than or equal to 0" % timeout)
+                raise InvalidTimeout(f"Timeout ({timeout}) cannot be less than or equal to 0")
 
             if self._expire and not self._lock_renewal_interval and timeout > self._expire:
-                raise TimeoutTooLarge("Timeout (%d) cannot be greater than expire (%d)" % (timeout, self._expire))
+                raise TimeoutTooLarge(f"Timeout ({timeout}) cannot be greater than expire ({self._expire})")
 
         busy = True
         blpop_timeout = timeout or self._expire or 0
@@ -234,16 +230,17 @@ class Lock(object):
                 elif blocking:
                     timed_out = not self._client.blpop(self._signal, blpop_timeout) and timeout
                 else:
-                    logger.debug("Failed to get %r.", self._name)
+                    logger_for_acquire.warning("Failed to acquire Lock(%r).", self._name)
                     return False
 
-        logger.debug("Got lock for %r.", self._name)
+        logger_for_acquire.info("Acquired Lock(%r).", self._name)
         if self._lock_renewal_interval is not None:
             self._start_lock_renewer()
         return True
 
     def extend(self, expire=None):
-        """Extends expiration time of the lock.
+        """
+        Extends expiration time of the lock.
 
         :param expire:
             New expiration time. If ``None`` - `expire` provided during
@@ -256,36 +253,31 @@ class Lock(object):
         elif self._expire is not None:
             expire = self._expire
         else:
-            raise TypeError(
-                "To extend a lock 'expire' must be provided as an "
-                "argument to extend() method or at initialization time."
-            )
+            raise TypeError("To extend a lock 'expire' must be provided as an argument to extend() method or at initialization time.")
 
         error = self.extend_script(client=self._client, keys=(self._name, self._signal), args=(self._id, expire))
         if error == 1:
-            raise NotAcquired("Lock %s is not acquired or it already expired." % self._name)
+            raise NotAcquired(f"Lock {self._name} is not acquired or it already expired.")
         elif error == 2:
-            raise NotExpirable("Lock %s has no assigned expiration time" % self._name)
+            raise NotExpirable(f"Lock {self._name} has no assigned expiration time")
         elif error:
-            raise RuntimeError("Unsupported error code %s from EXTEND script" % error)
+            raise RuntimeError(f"Unsupported error code {error} from EXTEND script")
 
     @staticmethod
-    def _lock_renewer(lockref, interval, stop):
+    def _lock_renewer(name, lockref, interval, stop):
         """
         Renew the lock key in redis every `interval` seconds for as long
         as `self._lock_renewal_thread.should_exit` is False.
         """
-        log = getLogger("%s.lock_refresher" % __name__)
         while not stop.wait(timeout=interval):
-            log.debug("Refreshing lock")
-            lock = lockref()
+            logger_for_refresh_thread.debug("Refreshing Lock(%r).", name)
+            lock: "Lock" = lockref()
             if lock is None:
-                log.debug("The lock no longer exists, "
-                          "stopping lock refreshing")
+                logger_for_refresh_thread.debug("Stopping loop because Lock(%r) was garbage collected.", name)
                 break
             lock.extend(expire=lock._expire)
             del lock
-        log.debug("Exit requested, stopping lock refreshing")
+        logger_for_refresh_thread.debug("Exiting renewal thread for Lock(%r).", name)
 
     def _start_lock_renewer(self):
         """
@@ -294,19 +286,21 @@ class Lock(object):
         if self._lock_renewal_thread is not None:
             raise AlreadyStarted("Lock refresh thread already started")
 
-        logger.debug(
-            "Starting thread to refresh lock every %s seconds",
-            self._lock_renewal_interval
+        logger_for_refresh_start.debug(
+            "Starting renewal thread for Lock(%r). Refresh interval: %s seconds.", self._name, self._lock_renewal_interval
         )
         self._lock_renewal_stop = threading.Event()
         self._lock_renewal_thread = threading.Thread(
             group=None,
             target=self._lock_renewer,
-            kwargs={'lockref': weakref.ref(self),
-                    'interval': self._lock_renewal_interval,
-                    'stop': self._lock_renewal_stop}
+            kwargs={
+                'name': self._name,
+                'lockref': weakref.ref(self),
+                'interval': self._lock_renewal_interval,
+                'stop': self._lock_renewal_stop,
+            },
         )
-        self._lock_renewal_thread.setDaemon(True)
+        self._lock_renewal_thread.demon = True
         self._lock_renewal_thread.start()
 
     def _stop_lock_renewer(self):
@@ -317,15 +311,16 @@ class Lock(object):
         """
         if self._lock_renewal_thread is None or not self._lock_renewal_thread.is_alive():
             return
-        logger.debug("Signalling the lock refresher to stop")
+        logger_for_refresh_shutdown.debug("Signaling renewal thread for Lock(%r) to exit.", self._name)
         self._lock_renewal_stop.set()
         self._lock_renewal_thread.join()
         self._lock_renewal_thread = None
-        logger.debug("Lock refresher has stopped")
+        logger_for_refresh_exit.debug("Renewal thread for Lock(%r) exited.", self._name)
 
     def __enter__(self):
         acquired = self.acquire(blocking=True)
-        assert acquired, "Lock wasn't acquired, but blocking=True"
+        if not acquired:
+            raise AssertionError(f"Lock({self._name}) wasn't acquired, but blocking=True was used!")
         return self
 
     def __exit__(self, exc_type=None, exc_value=None, traceback=None):
@@ -343,12 +338,12 @@ class Lock(object):
         """
         if self._lock_renewal_thread is not None:
             self._stop_lock_renewer()
-        logger.debug("Releasing %r.", self._name)
+        logger_for_release.debug("Releasing Lock(%r).", self._name)
         error = self.unlock_script(client=self._client, keys=(self._name, self._signal), args=(self._id, self._signal_expire))
         if error == 1:
-            raise NotAcquired("Lock %s is not acquired or it already expired." % self._name)
+            raise NotAcquired(f"Lock({self._name}) is not acquired or it already expired.")
         elif error:
-            raise RuntimeError("Unsupported error code %s from EXTEND script." % error)
+            raise RuntimeError(f"Unsupported error code {error} from EXTEND script.")
 
     def locked(self):
         """
