@@ -2,8 +2,8 @@ from __future__ import division
 from __future__ import print_function
 
 import gc
+import logging
 import multiprocessing
-import os
 import platform
 import sys
 import threading
@@ -26,9 +26,12 @@ from redis_lock import TimeoutNotUsable
 from redis_lock import TimeoutTooLarge
 from redis_lock import reset_all
 
-from conf import HELPER
-from conf import TIMEOUT
-from conf import UDS_PATH
+from config import HELPER
+from config import TIMEOUT
+
+pytest_plugins = ('pytester',)
+
+skipifpypy = partial(pytest.mark.skipif(platform.python_implementation() == 'PyPy'))
 
 
 def maybe_decode(data):
@@ -38,36 +41,49 @@ def maybe_decode(data):
         return data
 
 
-@pytest.yield_fixture
-def redis_server(scope='module'):
-    try:
-        os.unlink(UDS_PATH)
-    except OSError:
-        pass
-    with TestProcess('redis-server', '--port', '0', '--unixsocket', UDS_PATH) as process:
-        with dump_on_error(process.read):
-            wait_for_strings(process.read, TIMEOUT, "Running")
-            yield process
+@pytest.fixture(params=[True, False], ids=['decode_responses=True', 'decode_responses=False'])
+def make_conn_plain(request, redis_server, redis_socket):
+    def conn_factory(**options):
+        options.setdefault('encoding_errors', 'replace')
+        conn = StrictRedis(unix_socket_path=redis_socket, **options)
+        request.addfinalizer(conn.flushdb)
+        return conn
+
+    return conn_factory
 
 
-def make_conn_factory(addfinalizer, **options):
-    conn = StrictRedis(unix_socket_path=UDS_PATH, **options)
-    addfinalizer(conn.flushdb)
-
-    return conn
+@pytest.fixture(params=[True, False], ids=['decode_responses=True', 'decode_responses=False'])
+def make_conn(request, make_conn_plain):
+    return partial(make_conn_plain, decode_responses=request.param)
 
 
-@pytest.fixture(scope='function', params=[True, False], ids=['decode_responses=True', 'decode_responses=False'])
-def make_conn(request, redis_server):
-    """Redis connection factory."""
-    return partial(make_conn_factory, request.addfinalizer, decode_responses=request.param, encoding_errors='replace')
-
-
-@pytest.fixture(scope='function')
+@pytest.fixture
 def conn(request, make_conn):
     return make_conn()
 
 
+@pytest.fixture(
+    params=[
+        'normal',
+        'gevent',
+        pytest.param('eventlet', marks=skipifpypy(reason="apparently broken on PyPy")),
+    ]
+)
+def effect(request):
+    def wrap_name_with_effect(name):
+        if request.param == 'normal':
+            return name
+        else:
+            return '{}:{}'.format(name, request.param)
+
+    wrap_name_with_effect.expected_impl = {
+        'normal': '_thread',
+        'gevent': 'gevent.thread',
+        'eventlet': 'eventlet.green.thread',
+    }[request.param]
+    return wrap_name_with_effect
+
+
 @pytest.fixture
 def make_process(request):
     """Process factory, that makes processes, that terminate themselves
@@ -83,35 +99,62 @@ def make_process(request):
     return make_process_factory
 
 
-def test_upgrade(request, conn):
-    legacy_conn = make_conn_factory(request.addfinalizer, decode_responses=False)
+def test_upgrade(conn, make_conn_plain):
+    legacy_conn = make_conn_plain(decode_responses=False)
     lock = Lock(conn, "foobar")
     legacy_conn.set(lock._name, b'\xd6{\xc93\xe9\xbd,\xdb\xb6\xa8<\x8ax\xd1<\xb9', nx=True, ex=lock._expire)
     assert not lock.acquire(blocking=False)
 
 
-def test_simple(redis_server):
-    with TestProcess(sys.executable, HELPER, 'test_simple') as proc:
+def test_simple(redis_server, redis_socket, effect):
+    with TestProcess(sys.executable, HELPER, redis_socket, effect('test_simple')) as proc:
         with dump_on_error(proc.read):
             name = 'lock:foobar'
             wait_for_strings(
-                proc.read, TIMEOUT,
-                'Getting %r ...' % name,
-                'Got lock for %r.' % name,
-                'Releasing %r.' % name,
+                proc.read,
+                TIMEOUT,
+                'Acquiring Lock(%r) ...' % name,
+                'Acquired Lock(%r).' % name,
+                'Releasing Lock(%r).' % name,
                 'DIED.',
             )
 
 
-def test_no_block(conn):
+def test_simple_auto_renewal(redis_server, redis_socket, effect, LineMatcher):
+    with TestProcess(sys.executable, HELPER, redis_socket, effect('test_simple_auto_renewal')) as proc:
+        with dump_on_error(proc.read):
+            name = 'lock:foobar'
+            wait_for_strings(
+                proc.read,
+                TIMEOUT,
+                'DIED.',
+            )
+        LineMatcher(proc.read().splitlines()).fnmatch_lines(
+            [
+                '* threading.get_ident.__module__=%s' % effect.expected_impl,
+                '* Acquiring Lock(%r) ...' % name,
+                '* Acquired Lock(%r).' % name,
+                '* Starting renewal thread for Lock(%r). Refresh interval: 0.6666666666666666 seconds.' % name,
+                '* Refreshing Lock(%r).' % name,
+                '* Refreshing Lock(%r).' % name,
+                '* Signaling renewal thread for Lock(%r) to exit.' % name,
+                '* Exiting renewal thread for Lock(%r).' % name,
+                '* Renewal thread for Lock(%r) exited.' % name,
+                '* Releasing Lock(%r).' % name,
+            ]
+        )
+
+
+def test_no_block(conn, redis_socket):
     with Lock(conn, "foobar"):
-        with TestProcess(sys.executable, HELPER, 'test_no_block') as proc:
+        with TestProcess(sys.executable, HELPER, redis_socket, 'test_no_block') as proc:
             with dump_on_error(proc.read):
                 name = 'lock:foobar'
                 wait_for_strings(
-                    proc.read, TIMEOUT,
-                    'Getting %r ...' % name,
-                    'Failed to get %r.' % name,
+                    proc.read,
+                    TIMEOUT,
+                    'Acquiring Lock(%r) ...' % name,
+                    'Failed to acquire Lock(%r).' % name,
                     'acquire=>False',
                     'DIED.',
                 )
@@ -143,14 +186,15 @@ def test_timeout_expire_with_renewal(conn):
         assert lock.acquire(timeout=2) is False
 
 
-def test_timeout_acquired(conn):
-    with TestProcess(sys.executable, HELPER, 'test_timeout') as proc:
+def test_timeout_acquired(conn, redis_socket):
+    with TestProcess(sys.executable, HELPER, redis_socket, 'test_timeout') as proc:
         with dump_on_error(proc.read):
             name = 'lock:foobar'
             wait_for_strings(
-                proc.read, TIMEOUT,
-                'Getting %r ...' % name,
-                'Got lock for %r.' % name,
+                proc.read,
+                TIMEOUT,
+                'Acquiring Lock(%r) ...' % name,
+                'Acquired Lock(%r).' % name,
             )
             lock = Lock(conn, "foobar")
             assert lock.acquire(timeout=2)
@@ -196,17 +240,18 @@ def test_expire_int_conversion():
     assert lock._expire == 123
 
 
-def test_expire(conn):
+def test_expire(conn, redis_socket):
     lock = Lock(conn, "foobar", expire=TIMEOUT / 4)
     lock.acquire()
-    with TestProcess(sys.executable, HELPER, 'test_expire') as proc:
+    with TestProcess(sys.executable, HELPER, redis_socket, 'test_expire') as proc:
         with dump_on_error(proc.read):
             name = 'lock:foobar'
             wait_for_strings(
-                proc.read, TIMEOUT,
-                'Getting %r ...' % name,
-                'Got lock for %r.' % name,
-                'Releasing %r.' % name,
+                proc.read,
+                TIMEOUT,
+                'Acquiring Lock(%r) ...' % name,
+                'Acquired Lock(%r).' % name,
+                'Releasing Lock(%r).' % name,
                 'DIED.',
             )
     lock = Lock(conn, "foobar")
@@ -301,7 +346,7 @@ def test_plain(conn):
         time.sleep(0.01)
 
 
-def test_no_overlap(redis_server):
+def test_no_overlap(redis_server, redis_socket):
     """
     This test tries to simulate contention: lots of clients trying to acquire at the same time.
 
@@ -315,12 +360,12 @@ def test_no_overlap(redis_server):
     The subprocess being run (check helper.py) will fork bunch of processes and will try to
     syncronize them (using the builting sched) to try to acquire the lock at the same time.
     """
-    with TestProcess(sys.executable, HELPER, 'test_no_overlap') as proc:
+    with TestProcess(sys.executable, HELPER, redis_socket, 'test_no_overlap') as proc:
         with dump_on_error(proc.read):
             name = 'lock:foobar'
-            wait_for_strings(proc.read, 10 * TIMEOUT, 'Getting %r ...' % name)
-            wait_for_strings(proc.read, 10 * TIMEOUT, 'Got lock for %r.' % name)
-            wait_for_strings(proc.read, 10 * TIMEOUT, 'Releasing %r.' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Acquiring Lock(%r) ...' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Acquired Lock(%r).' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Releasing Lock(%r).' % name)
             wait_for_strings(proc.read, 10 * TIMEOUT, 'DIED.')
 
             class Event(object):
@@ -350,50 +395,48 @@ def test_no_overlap(redis_server):
                 for other in events.values():
                     if other is not event:
                         try:
-                            if (
-                                other.start < event.start < other.end or
-                                other.start < event.end < other.end
-                            ):
+                            if other.start < event.start < other.end or other.start < event.end < other.end:
                                 pytest.fail('%s overlaps %s' % (event, other))
                         except Exception:
                             print("[%s/%s]" % (event, other))
                             raise
 
 
-NWORKERS = 125
+def _no_overlap2_workerfn(redis_socket, event, count_lock, count):
+    logging.basicConfig(level=logging.DEBUG)
+    with StrictRedis(unix_socket_path=redis_socket) as conn:
+        redis_lock = Lock(conn, 'lock')
 
-
-@pytest.mark.skipif(platform.python_implementation() == 'PyPy', reason="This appears to be way too slow to run on PyPy")
-def test_no_overlap2(make_process, make_conn):
-    """The second version of contention test, that uses multiprocessing."""
-    go = multiprocessing.Event()
-    count_lock = multiprocessing.Lock()
-    count = multiprocessing.Value('H', 0)
-
-    def workerfn(go, count_lock, count):
-        redis_lock = Lock(make_conn(), 'lock')
         with count_lock:
             count.value += 1
 
-        go.wait()
+        event.wait()
 
         if redis_lock.acquire(blocking=True):
             with count_lock:
                 count.value += 1
 
-    for _ in range(NWORKERS):
-        make_process(target=workerfn, args=(go, count_lock, count)).start()
+
+@skipifpypy(reason="way too slow to run on PyPy")
+def test_no_overlap2(make_process, redis_server, redis_socket):
+    """The second version of contention test, that uses multiprocessing."""
+    event = multiprocessing.Event()
+    count_lock = multiprocessing.Lock()
+    count = multiprocessing.Value('H', 0)
+
+    for _ in range(125):
+        make_process(target=_no_overlap2_workerfn, args=(redis_socket, event, count_lock, count)).start()
 
     # Wait until all workers will come to point when they are ready to acquire
     # the redis lock.
-    while count.value < NWORKERS:
+    while count.value < 125:
         time.sleep(0.5)
 
     # Then "count" will be used as counter of workers, which acquired
     # redis-lock with success.
     count.value = 0
 
-    go.set()
+    event.set()
 
     time.sleep(1)
 
